import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="uniWeather",
    version="0.1.0",
    author="ResearchConcepts io GmbH",
    author_email="support@uniweather.io",
    description="Python client for the uniWeather cloud API",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/your_username/uniWeather",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.7",
    install_requires=[
        "requests>=2.0.0"
    ],
) 